/*******************************************************************************

  
  Copyright(c) 1999 - 2008 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  e1000 mailing list <e1000-devel@lists.sourceforge.net>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"


extern int clr;
extern int offset;

void dump_8254x_registers(volatile void *mem, u32 size, enum e1000_mac_type mac_type)
{
	unsigned int i, j, n;
	char name[16];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		case E1000_CTRL:
			sprintf(name, "CTRL"); break;
		case E1000_STATUS:
			sprintf(name, "STATUS"); break;
		case E1000_EECD:
			sprintf(name, "EEC"); break;
		case E1000_EERD:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "EERD"); break;
		case E1000_CTRL_EXT:
			sprintf(name, "CTRL_EXT"); break;
		case E1000_FLA:
			if ((mac_type != e1000_82541) && (mac_type != e1000_82547))
				continue;
			sprintf(name, "FLA"); break;
		case E1000_MDIC:
			sprintf(name, "MDIC"); break;
		case E1000_FCAL:
			sprintf(name, "FCAL"); break;
		case E1000_FCAH:
			sprintf(name, "FCAH"); break;
		case E1000_FCT:
			sprintf(name, "FCT"); break;
		case E1000_VET:
			sprintf(name, "VET"); break;
		case E1000_ICR:
			if (!clr) continue;
			sprintf(name, "ICR"); break;
		case E1000_ITR:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "ITR"); break;
		case E1000_ICS:
			sprintf(name, "ICS"); break;
		case E1000_IMS:
			sprintf(name, "IMS"); break;
		case E1000_IMC:
			sprintf(name, "IMC"); break;
		case E1000_RCTL:
			sprintf(name, "RCTL"); break;
		case E1000_FCTTV:
			sprintf(name, "FCTTV"); break;
		case E1000_TXCW:
			sprintf(name, "TXCW"); break;
		case E1000_RXCW:
			sprintf(name, "RXCW"); break;
		case E1000_TCTL:
			sprintf(name, "TCTL"); break;
		case E1000_TIPG:
			sprintf(name, "TIPG"); break;
		case E1000_TBT:
			if ((mac_type != e1000_82543) && (mac_type != e1000_82544))
				continue;
			sprintf(name, "TBT"); break;
		case E1000_AIT:
			sprintf(name, "AIT"); break;
		case E1000_LEDCTL:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "LEDCTL"); break;
		case E1000_PBA:
			sprintf(name, "PBA"); break;
		case E1000_ERT:
			if (mac_type != e1000_82543)
				continue;
			sprintf(name, "ERT"); break;
		case E1000_FCRTL:
			sprintf(name, "FCRTL"); break;
		case E1000_FCRTH:
			sprintf(name, "FCRTH"); break;
		case E1000_RDBAL(0):
			sprintf(name, "RDBAL"); break;
		case E1000_RDBAH(0):
			sprintf(name, "RDBAH"); break;
		case E1000_RDLEN(0):
			sprintf(name, "RDLEN"); break;
		case E1000_RDH(0):
			sprintf(name, "RDH"); break;
		case E1000_RDT(0):
			sprintf(name, "RDT"); break;
		case E1000_RDTR:
			sprintf(name, "RDTR"); break;
		case E1000_RXDCTL(0):
			sprintf(name, "RXDCTL"); break;
		case E1000_RADV:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "RADV"); break;
		case E1000_RSRPD:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "RSRPD"); break;
		case E1000_TXDMAC:
			sprintf(name, "TXDMAC"); break;
		case E1000_TDFH:
			sprintf(name, "TDFH"); break;
		case E1000_TDFT:
			sprintf(name, "TDFT"); break;
		case E1000_TDFHS:
			sprintf(name, "TDFHS"); break;
		case E1000_TDFTS:
			sprintf(name, "TDFTS"); break;
		case E1000_TDFPC:
			sprintf(name, "TDFPC"); break;
		case E1000_TDBAL(0):
			sprintf(name, "TDBAL"); break;
		case E1000_TDBAH(0):
			sprintf(name, "TDBAH"); break;
		case E1000_TDLEN(0):
			sprintf(name, "TDLEN"); break;
		case E1000_TDH(0):
			sprintf(name, "TDH"); break;
		case E1000_TDT(0):
			sprintf(name, "TDT"); break;
		case E1000_TIDV:
			sprintf(name, "TIDV"); break;
		case E1000_TXDCTL(0):
			sprintf(name, "TXDCTL"); break;
		case E1000_TADV:
			sprintf(name, "TADV"); break;
		case E1000_TSPMT:
			if (mac_type == e1000_82543)
				continue;
			sprintf(name, "TSPMT"); break;
		case E1000_CRCERRS:
			if (!clr) continue;
			sprintf(name, "CRCERRS"); break;
		case E1000_ALGNERRC:
			if (!clr) continue;
			sprintf(name, "ALGNERRC"); break;
		case E1000_SYMERRS:
			if (!clr) continue;
			sprintf(name, "SYMERRS"); break;
		case E1000_RXERRC:
			if (!clr) continue;
			sprintf(name, "RXERRC"); break;
		case E1000_MPC:
			if (!clr) continue;
			sprintf(name, "MPC"); break;
		case E1000_SCC:
			if (!clr) continue;
			sprintf(name, "SCC"); break;
		case E1000_ECOL:
			if (!clr) continue;
			sprintf(name, "ECOL"); break;
		case E1000_MCC:
			if (!clr) continue;
			sprintf(name, "MCC"); break;
		case E1000_LATECOL:
			if (!clr) continue;
			sprintf(name, "LATECOL"); break;
		case E1000_COLC:
			if (!clr) continue;
			sprintf(name, "COLC"); break;
		case E1000_DC:
			if (!clr) continue;
			sprintf(name, "DC"); break;
		case E1000_TNCRS:
			if (!clr) continue;
			sprintf(name, "TNCRS"); break;
		case E1000_SEC:
			if (!clr) continue;
			sprintf(name, "SEC"); break;
		case E1000_CEXTERR:
			if (!clr) continue;
			sprintf(name, "CEXTERR"); break;
		case E1000_RLEC:
			if (!clr) continue;
			sprintf(name, "RLEC"); break;
		case E1000_XONRXC:
			if (!clr) continue;
			sprintf(name, "XONRXC"); break;
		case E1000_XONTXC:
			if (!clr) continue;
			sprintf(name, "XONTXC"); break;
		case E1000_XOFFRXC:
			if (!clr) continue;
			sprintf(name, "XOFFRXC"); break;
		case E1000_XOFFTXC:
			if (!clr) continue;
			sprintf(name, "XOFFTXC"); break;
		case E1000_FCRUC:
			if (!clr) continue;
			sprintf(name, "FCRUC"); break;
		case E1000_PRC64:
			if (!clr) continue;
			sprintf(name, "PRC64"); break;
		case E1000_PRC127:
			if (!clr) continue;
			sprintf(name, "PRC127"); break;
		case E1000_PRC255:
			if (!clr) continue;
			sprintf(name, "PRC255"); break;
		case E1000_PRC511:
			if (!clr) continue;
			sprintf(name, "PRC511"); break;
		case E1000_PRC1023:
			if (!clr) continue;
			sprintf(name, "PRC1023"); break;
		case E1000_PRC1522:
			if (!clr) continue;
			sprintf(name, "PRC1522"); break;
		case E1000_GPRC:
			if (!clr) continue;
			sprintf(name, "GPRC"); break;
		case E1000_BPRC:
			if (!clr) continue;
			sprintf(name, "BPRC"); break;
		case E1000_MPRC:
			if (!clr) continue;
			sprintf(name, "MPRC"); break;
		case E1000_GPTC:
			if (!clr) continue;
			sprintf(name, "GPTC"); break;
		case E1000_GORCL:
			if (!clr) continue;
			sprintf(name, "GORCL"); break;
		case E1000_GORCH:
			if (!clr) continue;
			sprintf(name, "GORCH"); break;
		case E1000_GOTCL:
			if (!clr) continue;
			sprintf(name, "GOTCL"); break;
		case E1000_GOTCH:
			if (!clr) continue;
			sprintf(name, "GOTCH"); break;
		case E1000_RNBC:
			if (!clr) continue;
			sprintf(name, "RNBC"); break;
		case E1000_RUC:
			if (!clr) continue;
			sprintf(name, "RUC"); break;
		case E1000_RFC:
			if (!clr) continue;
			sprintf(name, "RFC"); break;
		case E1000_ROC:
			if (!clr) continue;
			sprintf(name, "ROC"); break;
		case E1000_RJC:
			if (!clr) continue;
			sprintf(name, "RJC"); break;
		case E1000_MGTPRC:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544) || !clr)
				continue;
			sprintf(name, "MGTPRC"); break;
		case E1000_MGTPDC:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544) || !clr)
				continue;
			sprintf(name, "MGTPDC"); break;
		case E1000_MGTPTC:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544) || !clr)
				continue;
			sprintf(name, "MGTPTC"); break;
		case E1000_TORL:
			if (!clr) continue;
			sprintf(name, "TORL"); break;
		case E1000_TORH:
			if (!clr) continue;
			sprintf(name, "TORH"); break;
		case E1000_TOTL:
			if (!clr) continue;
			sprintf(name, "TOTL"); break;
		case E1000_TOTH:
			if (!clr) continue;
			sprintf(name, "TOTH"); break;
		case E1000_TPR:
			if (!clr) continue;
			sprintf(name, "TPR"); break;
		case E1000_TPT:
			if (!clr) continue;
			sprintf(name, "TPT"); break;
		case E1000_PTC64:
			if (!clr) continue;
			sprintf(name, "PTC64"); break;
		case E1000_PTC127:
			if (!clr) continue;
			sprintf(name, "PTC127"); break;
		case E1000_PTC255:
			if (!clr) continue;
			sprintf(name, "PTC255"); break;
		case E1000_PTC511:
			if (!clr) continue;
			sprintf(name, "PTC511"); break;
		case E1000_PTC1023:
			if (!clr) continue;
			sprintf(name, "PTC1023"); break;
		case E1000_PTC1522:
			if (!clr) continue;
			sprintf(name, "PTC1522"); break;
		case E1000_MPTC:
			if (!clr) continue;
			sprintf(name, "MPTC"); break;
		case E1000_BPTC:
			if (!clr) continue;
			sprintf(name, "BPTC"); break;
		case E1000_TSCTC:
			if (!clr) continue;
			sprintf(name, "TSCTC"); break;
		case E1000_TSCTFC:
			if (!clr) continue;
			sprintf(name, "TSCTFC"); break;
		case E1000_RXCSUM:
			sprintf(name, "RXCSUM"); break;
		case E1000_MTA:
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "MTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_RA:
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "RAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "RAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_VFTA:
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "VFTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case E1000_WUC:
			if (mac_type == e1000_82543) continue;
			sprintf(name, "WUC"); break;
		case E1000_WUFC:
			if (mac_type == e1000_82543) continue;
			sprintf(name, "WUFC"); break;
		case E1000_WUS:
			if (mac_type == e1000_82543) continue;
			sprintf(name, "WUS"); break;
		case E1000_MANC:
			if ((mac_type == e1000_82543) || (mac_type == e1000_82544))
				continue;
			sprintf(name, "MANC"); break;
		case E1000_IPAV:
			if (mac_type == e1000_82543) continue;
			sprintf(name, "IPAV"); break;
		case E1000_WUPL:
			if (mac_type == e1000_82543) continue;
			sprintf(name, "WUPL"); break;
		case E1000_FFLT:
			if (mac_type != e1000_82543)
				for (j=i, n=0; n<4; n++) {
					sprintf(name, "FFLT[%d]", n);
					printit32(j, name, mem);
					j += sizeof(u32);
				}
			continue;
		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
